@@ -1,7 +1,10 @@
 from typing import Union, Sequence
 from pathlib import Path
+from sqlite3 import Connection
 
 PathIsh = Union[str, Path]
+# a path or a connection to a database
+PathIshOrConn = Union[PathIsh, Connection]
 
 
 def expand_path(path: PathIsh) -> Path:
